
/* Chrysalide - Outil d'analyse de fichiers binaires
 * core.c - prototypes pour le calcul d'encodages
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "core.h"


#include <analysis/scan/core.h>
#include <plugins/self.h>


#ifdef INCLUDE_PYTHON3_BINDINGS
#   include "python/module.h"
#   include "python/classics/module.h"
#endif
#include "classics/djb2.h"
#include "classics/ror13.h"


#ifdef INCLUDE_PYTHON3_BINDINGS_
#   define PG_REQ RL("PyChrysalide")
#else
#   define PG_REQ NO_REQ
#endif



DEFINE_CHRYSALIDE_PLUGIN("ApiHashing", "API hash computing as ROST modifiers",
                         PACKAGE_VERSION, CHRYSALIDE_WEBSITE("doc/formats"),
                         PG_REQ, AL(PGA_PLUGIN_INIT));



/******************************************************************************
*                                                                             *
*  Paramètres  : plugin = greffon à manipuler.                                *
*                                                                             *
*  Description : Prend acte du chargement du greffon.                         *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

G_MODULE_EXPORT bool chrysalide_plugin_init(GPluginModule *plugin)
{
    bool result;                            /* Bilan à retourner           */

    result = true;

#define REGISTER_SCAN_MODIFIER(m)                       \
    ({                                                  \
        GScanTokenModifier *__mod;                      \
        bool __status;                                  \
        __mod = m;                                      \
        __status = register_scan_token_modifier(__mod); \
        g_object_unref(G_OBJECT(__mod));                \
        __status;                                       \
    })

    if (result) result = REGISTER_SCAN_MODIFIER(g_scan_djb2_modifier_new());
    if (result) result = REGISTER_SCAN_MODIFIER(g_scan_ror13_modifier_new());

#ifdef INCLUDE_PYTHON3_BINDINGS

    if (result) result = add_apihashing_module_to_python_module();
    if (result) result = register_apihashing_classics_modifiers();

#endif

    return result;

}
